pub struct AddressLookupRemoval {
pub node_id: String,
pub has_remaining_contributions: bool,
pub remaining_addrs: Vec<String>,
}Expand description
Result of removing one service-instance contribution.
Fields
node_id: StringCanonical lowercase-base32 node id of the removed instance.
has_remaining_contributions: boolWhether another live instance in this browse source still advertises this node, independent of whether that contribution currently has a dialable address.
remaining_addrs: Vec<String>Effective addresses still contributed for that node by other live instances in this browse source.