pub struct AddressLookupUpsert {
pub node_id: String,
pub effective_addrs: Vec<String>,
pub replaced: Option<AddressLookupRemoval>,
}Expand description
Effective state changes produced by a successful contribution upsert.
Fields
node_id: StringCanonical lowercase-base32 node id of the inserted contribution.
effective_addrs: Vec<String>This browse source’s effective address union for the newly advertised node after the update.
replaced: Option<AddressLookupRemoval>Transition for the previously advertised node when this service
instance changed endpoint identity. This is None for a new instance
or an update that retains the same parsed endpoint id.