Module session

Module session 

Session — a QUIC connection to a single remote peer.

session_connect establishes (or reuses a pooled) connection and returns an opaque handle. Bidirectional streams, unidirectional streams, and datagrams are all accessible through the session handle.

Structs

CloseInfo
Close information returned when a session ends.

Functions

session_accept
Accept an incoming session (QUIC connection) from a remote peer.
session_close
Close a session and remove it from the registry.
session_closed
Wait for the session to close and return the close information.
session_connect
Establish a session (QUIC connection) to a remote peer.
session_create_bidi_stream
Open a new bidirectional stream on an existing session.
session_create_uni_stream
Open a new unidirectional (send-only) stream on an existing session.
session_max_datagram_size
Return the current maximum datagram payload size for this session.
session_next_bidi_stream
Accept the next incoming bidirectional stream from the remote side.
session_next_uni_stream
Accept the next incoming unidirectional (receive-only) stream.
session_ready
Wait for the QUIC handshake to complete on a session.
session_recv_datagram
Receive the next datagram from the session.
session_remote_id
Return the remote peer’s public key for a session.
session_send_datagram
Send a datagram on the session.