pub async fn session_closed(
endpoint: &IrohEndpoint,
session_handle: u64,
) -> Result<CloseInfo, CoreError>Expand description
Wait for the session to close and return the close information.
Blocks until the connection is closed by either side. Removes the session from the registry so resources are freed.