Session — a QUIC connection to a single remote peer.
session_connect establishes (or reuses a pooled) connection and returns
an opaque handle. Bidirectional streams, unidirectional streams, and
datagrams are all accessible through the session handle.
Structs
- Close
Info - Close information returned when a session ends.
Functions
- session_
accept - Accept an incoming session (QUIC connection) from a remote peer.
- session_
close - Close a session and remove it from the registry.
- session_
closed - Wait for the session to close and return the close information.
- session_
connect - Establish a session (QUIC connection) to a remote peer.
- session_
create_ bidi_ stream - Open a new bidirectional stream on an existing session.
- session_
create_ uni_ stream - Open a new unidirectional (send-only) stream on an existing session.
- session_
max_ datagram_ size - Return the current maximum datagram payload size for this session.
- session_
next_ bidi_ stream - Accept the next incoming bidirectional stream from the remote side.
- session_
next_ uni_ stream - Accept the next incoming unidirectional (receive-only) stream.
- session_
ready - Wait for the QUIC handshake to complete on a session.
- session_
recv_ datagram - Receive the next datagram from the session.
- session_
remote_ id - Return the remote peer’s public key for a session.
- session_
send_ datagram - Send a datagram on the session.